@@ -1,20 +1,8 @@
 /*
-   This file is part of the KDE libraries
-   Copyright (c) 1999 Waldo Bastian <bastian@kde.org>
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1999 Waldo Bastian <bastian@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef _KLAUNCHER_H_
@@ -43,7 +31,7 @@ typedef unsigned int pid_t;
 #include <QDBusMessage>
 #include <QDBusContext>
 
-#include <kservice.h>
+#include <KService>
 #include <kio/idleslave.h>
 #include <kio/connectionserver.h>
 
@@ -105,7 +93,7 @@ public:
     KLauncher();
 #endif
 
-    ~KLauncher();
+    ~KLauncher() override;
 
     void close();
 
